@@ -39,7 +39,7 @@ SEXP hitandrun_bbReject(SEXP _lb, SEXP _ub, SEXP _constr, SEXP _rhs, SEXP _niter
 			for (int j = 0; j < n; ++j) {
 				x[j] = lb[j] + d[j] * unif_rand();
 			}
-			if (hitandrun_hit(&constr, rhs, x)) {
+			if (hitandrun_hit(&constr, rhs, x, 0.0)) {
 				wasHit = 1;
 				writeRow(&result, i, x);
 			} else {
